parse_int

Macro parse_int 

macro_rules! parse_int {
    ($bytes: expr, $ty: ty) => { ... };
}
A macro to parse a byte slice into a specified integer type.

Arguments

  • $bytes - The byte slice to parse.
  • $ty - The integer type to parse the bytes into.

Panics

This macro will panic if the byte slice cannot be converted into the specified integer type.